import { Button, Color, CssProperty, Property, Style, booleanConverter } from '@nativescript/core';
import { BoxType, CheckBoxBase, checkedProperty, cssProperty, fillColorProperty, tintColorProperty } from './common';
const checkBoxBackgroundColorProperty = new CssProperty({
    name: 'checkBoxBackgroundColor',
    cssName: 'checkbox-background-color',
    valueConverter: (v) => String(v)
});
const onCheckColorProperty = new CssProperty({
    name: 'onCheckColor',
    cssName: 'on-check-color',
    defaultValue: '#ffffff',
    valueConverter: (v) => String(v)
});
const onTintColorProperty = new CssProperty({
    name: 'onTintColor',
    cssName: 'on-tint-color',
    valueConverter: (v) => String(v)
});
const onFillColorProperty = new CssProperty({
    name: 'onFillColor',
    cssName: 'on-fill-color',
    valueConverter: (v) => String(v)
});
const boxTypeProperty = new Property({
    name: 'boxType',
    valueConverter: (v) => (BoxType[v] === BoxType.circle ? 0 : 1)
});
function getIOSColor(value) {
    var _a;
    return (_a = (!value || value instanceof Color ? value : new Color(value))) === null || _a === void 0 ? void 0 : _a.ios;
}
export class CheckBox extends CheckBoxBase {
    constructor() {
        super(...arguments);
        this._lineWidth = 1;
    }
    createNativeView() {
        const view = super.createNativeView();
        this._iosCheckbox = BEMCheckBox.alloc().initWithFrame(CGRectMake(0, 0, 80, 80));
        view.addSubview(this._iosCheckbox);
        return view;
    }
    [fillColorProperty.setNative](value) {
        this._iosCheckbox.onFillColor = getIOSColor(value);
    }
    [onFillColorProperty.setNative](value) {
        this._iosCheckbox.onFillColor = getIOSColor(value);
    }
    [tintColorProperty.setNative](value) {
        this._iosCheckbox.tintColor = getIOSColor(value);
    }
    [onCheckColorProperty.setNative](value) {
        this._iosCheckbox.onCheckColor = getIOSColor(value);
    }
    [checkBoxBackgroundColorProperty.setNative](value) {
        this._iosCheckbox.offFillColor = getIOSColor(value);
    }
    [boxTypeProperty.setNative](value) {
        if (this.nativeViewProtected) {
            this._iosCheckbox.boxType = value;
        }
    }
    [checkedProperty.setNative](value) {
        this._iosCheckbox.setOnAnimated(value, true);
    }
    set checkedAnimated(value) {
        this._iosCheckbox.setOnAnimated(value, true);
    }
    set lineWidth(value) {
        this._iosCheckbox.lineWidth = value;
        this._lineWidth = value;
    }
    set hideBox(value) {
        this._iosCheckbox.hideBox = value;
        this._hideBox = value;
    }
    set animationDuration(value) {
        this._iosCheckbox.animationDuration = value;
        this._animationDuration = value;
    }
    set onAnimationType(value) {
        if (this._iosCheckbox) {
            this._iosCheckbox.onAnimationType = this._getAnimationType(value);
        }
        else
            this._onAnimationType = value;
    }
    set offAnimationType(value) {
        this._iosCheckbox.offAnimationType = this._getAnimationType(value);
        this._offAnimationType = value;
    }
    get nativeiOSCheckBox() {
        return this._iosCheckbox;
    }
    reload(value) {
        this._iosCheckbox.reload();
    }
    initNativeView() {
        this.addEventListener('tap', (args) => {
            this.tapTimeout = setTimeout(() => {
                this.tapTimeout = null;
                const checkbox = args.object;
                checkbox.checked = !checkbox.checked;
            }, 10);
        });
        this._onAnimationType = 2;
        this._offAnimationType = 2;
        this._delegate = BEMCheckBoxDelegateImpl.initWithOwner(new WeakRef(this));
        let fontSize;
        if (!this.style.fontSize) {
            fontSize = 15;
        }
        else {
            fontSize = this.style.fontSize;
        }
        this._iosCheckbox.delegate = this._delegate;
        this._iosCheckbox.frame = CGRectMake(0, 0, fontSize, fontSize);
        this._iosCheckbox.center = CGPointMake(this._iosCheckbox.center.x, fontSize / 2 + 3);
        this.style.paddingLeft = fontSize + (fontSize > 20 ? 10 : 5);
        this.style.textAlignment = 'left';
        if (typeof this._lineWidth !== 'undefined') {
            this.lineWidth = this._lineWidth;
        }
        if (typeof this._hideBox !== 'undefined') {
            this.hideBox = this._hideBox;
        }
        this.boxType = this.boxType === 0 ? 0 : 1;
        if (typeof this._animationDuration !== 'undefined') {
            this.animationDuration = this._animationDuration;
        }
        if (typeof this._onAnimationType !== 'undefined') {
            this.onAnimationType = this._onAnimationType;
        }
        if (typeof this._offAnimationType !== 'undefined') {
            this.offAnimationType = this._offAnimationType;
        }
    }
    disposeNativeView() {
        this._iosCheckbox.delegate = null;
        this._iosCheckbox = null;
        this.removeEventListener('tap');
    }
    toggle() {
        this.checked = !this.checked;
    }
    _getAnimationType(value) {
        switch (value) {
            case 1:
                return 0;
            case 2:
                return 1;
            case 3:
                return 2;
            case 4:
                return 3;
            case 5:
                return 0;
            case 6:
                return 5;
            default:
                return 0;
        }
    }
}
__decorate([
    cssProperty
], CheckBox.prototype, "onCheckColor", void 0);
__decorate([
    cssProperty
], CheckBox.prototype, "checkBoxBackgroundColor", void 0);
__decorate([
    cssProperty
], CheckBox.prototype, "onTintColor", void 0);
__decorate([
    cssProperty
], CheckBox.prototype, "onFillColor", void 0);
var BEMCheckBoxDelegateImpl = /** @class */ (function (_super) {
    __extends(BEMCheckBoxDelegateImpl, _super);
    function BEMCheckBoxDelegateImpl() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /* static ObjCExposedMethods = {
     "didTapCheckBox": { returns: interop.types.void, params: [NSObject] }
     };*/
    BEMCheckBoxDelegateImpl.initWithOwner = function (owner) {
        var delegate = BEMCheckBoxDelegateImpl.new();
        delegate._owner = owner;
        return delegate;
    };
    BEMCheckBoxDelegateImpl.prototype.animationDidStopForCheckBox = function (checkBox) {
        // TODO: Maybe trigger event later?
    };
    BEMCheckBoxDelegateImpl.prototype.didTapCheckBox = function (checkBox) {
        var owner = this._owner.get();
        if (owner) {
            if (owner.tapTimeout) {
                clearTimeout(owner.tapTimeout);
                owner.tapTimeout = null;
            }
            checkedProperty.nativeValueChange(owner, checkBox.on);
        }
    };
    BEMCheckBoxDelegateImpl.ObjCProtocols = [BEMCheckBoxDelegate];
    return BEMCheckBoxDelegateImpl;
}(NSObject));
function onCheckedPropertyChanged(checkbox, oldValue, newValue) {
    checkbox._onCheckedPropertyChanged(checkbox, oldValue, newValue);
}
boxTypeProperty.register(CheckBox);
onTintColorProperty.register(Style);
onCheckColorProperty.register(Style);
checkBoxBackgroundColorProperty.register(Style);
//# sourceMappingURL=index.ios.js.map